==> flink-1.12.7-src.tgz: flink-1.12.7/flink-runtime/src/main/java/org/apache/flink/runtime/scheduler/SlotSharingStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.scheduler;

import org.apache.flink.runtime.jobmanager.scheduler.CoLocationGroupDesc;
import org.apache.flink.runtime.jobmanager.scheduler.SlotSharingGroup;
import org.apache.flink.runtime.scheduler.strategy.ExecutionVertexID;
import org.apache.flink.runtime.scheduler.strategy.SchedulingTopology;

import java.util.Set;

/** Strategy which determines {@link ExecutionSlotSharingGroup} for each execution vertex. */
interface SlotSharingStrategy {

    ExecutionSlotSharingGroup getExecutionSlotSharingGroup(ExecutionVertexID executionVertexId);

    Set<ExecutionSlotSharingGroup> getExecutionSlotSharingGroups();

    @FunctionalInterface
    interface Factory {
        SlotSharingStrategy create(
                SchedulingTopology topology,
                Set<SlotSharingGroup> logicalSlotSharingGroups,
                Set<CoLocationGroupDesc> coLocationGroups);
    }
}

==> flink-1.19.2-src.tgz: flink-1.19.2/flink-runtime/src/main/java/org/apache/flink/runtime/scheduler/SlotSharingStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.scheduler;

import org.apache.flink.runtime.jobmanager.scheduler.CoLocationGroup;
import org.apache.flink.runtime.jobmanager.scheduler.SlotSharingGroup;
import org.apache.flink.runtime.scheduler.strategy.ExecutionVertexID;
import org.apache.flink.runtime.scheduler.strategy.SchedulingTopology;

import java.util.Set;

/** Strategy which determines {@link ExecutionSlotSharingGroup} for each execution vertex. */
interface SlotSharingStrategy {

    ExecutionSlotSharingGroup getExecutionSlotSharingGroup(ExecutionVertexID executionVertexId);

    Set<ExecutionSlotSharingGroup> getExecutionSlotSharingGroups();

    @FunctionalInterface
    interface Factory {
        SlotSharingStrategy create(
                SchedulingTopology topology,
                Set<SlotSharingGroup> logicalSlotSharingGroups,
                Set<CoLocationGroup> coLocationGroups);
    }
}
